@@ -3,7 +3,7 @@ from typing import Optional
 
 import click
 
-from .main import convert_table_file_to_insert_statement
+from .main import TYPES_MAP, convert_table_file_to_insert_statement
 
 logger = logging.getLogger()
 
@@ -17,23 +17,28 @@ logger = logging.getLogger()
     "--output-table",
     required=True,
     type=str,
-    help="Name of table to use in SQL insert statement",
+    help="Name of table to use in SQL insert statement.",
+)
+@click.option(
+    "--delimiter", default=",", type=str, help="Delimiter of CSV file.", show_default=True
 )
-@click.option("--delimiter", default=",", type=str, help="Delimiter of CSV file", show_default=True)
 @click.option(
     "--has-types-row",
     is_flag=True,
-    help="If file contains row with types as row 1",
+    help=(
+        "If file contains row with types as row 1 (second row in file). "
+        f"Available types: {', '.join(TYPES_MAP.keys())}."
+    ),
 )
-@click.option("--output-file", default=None, help="Name of file to write SQL insert to")
-def cli(
+@click.option("--output-file", default=None, help="Name of file to write SQL insert to.")
+def table2sql(
     path_to_file: str,
     output_table: str,
     delimiter: Optional[str],
     has_types_row: Optional[bool],
     output_file: Optional[str],
 ):
-    """Converts given table file to SQL insert statements."""
+    """Converts given table file to SQL insert statements and prints it."""
 
     insert_statement = convert_table_file_to_insert_statement(
         path_to_file=path_to_file,
