@@ -16,6 +16,7 @@ TYPES_MAP = {
     "float": float,
     "str": lambda value: f"'{value}'",
     "sql": lambda sql: sql,
+    "null": lambda _: "NULL",
 }
 
 
@@ -26,10 +27,13 @@ def _get_columns_formatted(column_names: Iterable[str]):
 def _get_values_formatted(values: Iterable[str], types: Optional[List[Callable]]):
     values_ = []
     for row in values:
+
         if types:
-            row = [str(type_(value)) for type_, value in zip(types, row)]
+            row = [
+                "NULL" if value is None else str(type_(value)) for type_, value in zip(types, row)
+            ]
         else:
-            row = [str(value) for value in row]
+            row = ["NULL" if value is None else str(value) for value in row]
         values_.append(f'({", ".join(row)})')
 
     return ", ".join(values_)
@@ -46,8 +50,8 @@ def _get_insert_statement_formatted(
 def _get_types_functions(types_str: Tuple[str, ...]):
     types_functions = []
     for type_str in types_str:
+        type_str = type_str.lower()
         try:
-
             type_ = TYPES_MAP[type_str]
         except KeyError:
             type_ = str
@@ -64,9 +68,14 @@ def _get_file_extension(file_path: str):
 
 
 def convert_table_file_to_insert_statement(
-    path_to_file: str, output_table: str, delimiter=str, has_types_row=bool, sheet_name=None
+    path_to_file: str,
+    output_table: str,
+    delimiter: Optional[str] = ",",
+    has_types_row: Optional[bool] = False,
+    sheet_name: Optional[str] = None,
 ):
-    """Converts CSV file to SQL insert statements.
+    # noqa: E501
+    """Converts table file (CSV or Excel) to SQL insert statements.
 
     If file doesn't contain row with types as second row - every value is treated as string and
     will be available in insert statement with single quotes.
@@ -85,6 +94,27 @@ def convert_table_file_to_insert_statement(
 
     Returns:
         str: SQL insert statement
+
+    Example:
+    ```python
+    from table2sql import convert_table_file_to_insert_statement
+
+    ## some.csv
+    # a,b,c,d
+    # int,str,float,sql
+    # 1,2,3,(SELECT id FROM another.table WHERE name = 'Paul')
+    # 5,6,7,(SELECT id FROM another.table WHERE name = 'Paul')
+
+    inserts = convert_table_file_to_insert_statement(
+        path_to_file="some.csv",
+        output_table="test.table",
+        has_types_row=True,
+    )
+
+    print(inserts)
+    # INSERT INTO some.table (a, b, c, d)
+    # VALUES (1, '2', 3.0, (SELECT id FROM another.table WHERE name = 'Paul')), (5, '6', 7.0, (SELECT id FROM another.table WHERE name = 'Paul'));
+    ```
     """
 
     file_extension = _get_file_extension(path_to_file)
